From bb0613a5d5d424407828ac19d0908b191b489f14 Mon Sep 17 00:00:00 2001
From: Pierre Muller <muller@sourceware.org>
Date: Mon, 21 Sep 2009 22:37:59 +0000
Subject: [PATCH] 	* windows-nat.c (ctrl_c_handler): Also handle
 CTRL_BREAK_EVENT.

---
 gdb/ChangeLog     | 4 ++++
 gdb/windows-nat.c | 4 ++--
 2 files changed, 6 insertions(+), 2 deletions(-)

diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 63f0ca4ced5..2687d38292a 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,7 @@
+2009-09-22  Pierre Muller  <muller@ics.u-strasbg.fr>
+
+	* windows-nat.c (ctrl_c_handler): Also handle CTRL_BREAK_EVENT.
+
 2009-09-18  Keith Seitz  <keiths@redhat.com>
 
 	* cp-support.h (cp_validate_operator): Declare new function.
diff --git a/gdb/windows-nat.c b/gdb/windows-nat.c
index c041c429e91..d8c2599b244 100644
--- a/gdb/windows-nat.c
+++ b/gdb/windows-nat.c
@@ -1289,8 +1289,8 @@ ctrl_c_handler (DWORD event_type)
 {
   const int attach_flag = current_inferior ()->attach_flag;
 
-  /* Only handle Ctrl-C event.  Ignore others.  */
-  if (event_type != CTRL_C_EVENT)
+  /* Only handle Ctrl-C and Ctrl-Break events.  Ignore others.  */
+  if (event_type != CTRL_C_EVENT && event_type != CTRL_BREAK_EVENT)
     return FALSE;
 
   /* If the inferior and the debugger share the same console, do nothing as
-- 
GitLab